# Local
from .api import (
    Config,
    ConfigDict,
    Option,
    SConfig,
    from_dataclass,
    from_dict,
    merge_dict,
)

__version__ = "0.10.0"

__all__ = [
    "Config",
    "ConfigDict",
    "Option",
    "SConfig",
    "from_dataclass",
    "from_dict",
    "merge_dict",
]
